==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebInputBaseDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebInputBaseDescription = /*@__PURE__*/ (() => {
    class WebInputBaseDescription extends Description {
        constructor() {
            super();
            this.r = null;
            this.g = false;
            this.i = false;
            this.f = false;
            this.h = false;
            this.s = null;
            this.q = null;
            this.t = null;
            this.p = null;
            this.o = null;
            this.n = null;
        }
        get_type() {
            return "WebInputBase";
        }
        get type() {
            return this.get_type();
        }
        get name() {
            return this.r;
        }
        set name(a) {
            this.r = a;
            this.e("Name");
        }
        get outlined() {
            return this.g;
        }
        set outlined(a) {
            this.g = a;
            this.e("Outlined");
        }
        get required() {
            return this.i;
        }
        set required(a) {
            this.i = a;
            this.e("Required");
        }
        get disabled() {
            return this.f;
        }
        set disabled(a) {
            this.f = a;
            this.e("Disabled");
        }
        get readonly() {
            return this.h;
        }
        set readonly(a) {
            this.h = a;
            this.e("Readonly");
        }
        get placeholder() {
            return this.s;
        }
        set placeholder(a) {
            this.s = a;
            this.e("Placeholder");
        }
        get label() {
            return this.q;
        }
        set label(a) {
            this.q = a;
            this.e("Label");
        }
        get size() {
            return this.t;
        }
        set size(a) {
            this.t = a;
            this.e("Size");
        }
        get inputOcurredRef() {
            return this.p;
        }
        set inputOcurredRef(a) {
            this.p = a;
            this.e("InputOcurredRef");
        }
        get focusRef() {
            return this.o;
        }
        set focusRef(a) {
            this.o = a;
            this.e("FocusRef");
        }
        get blurRef() {
            return this.n;
        }
        set blurRef(a) {
            this.n = a;
            this.e("BlurRef");
        }
    }
    WebInputBaseDescription.$t = /*@__PURE__*/ markType(WebInputBaseDescription, 'WebInputBaseDescription', Description.$);
    return WebInputBaseDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/WebInputBaseDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let WebInputBaseDescription = /*@__PURE__*/ (() => {
    class WebInputBaseDescription extends Description {
        get_type() {
            return "WebInputBase";
        }
        get type() {
            return this.get_type();
        }
        constructor() {
            super();
            this.j = false;
            this.k = false;
            this.y = null;
            this.w = null;
            this.h = false;
            this.l = false;
            this.r = null;
            this.x = null;
            this.i = false;
            this.v = null;
            this.u = null;
            this.t = null;
        }
        get outlined() {
            return this.j;
        }
        set outlined(a) {
            this.j = a;
            this.g("Outlined");
        }
        get readOnly() {
            return this.k;
        }
        set readOnly(a) {
            this.k = a;
            this.g("ReadOnly");
        }
        get placeholder() {
            return this.y;
        }
        set placeholder(a) {
            this.y = a;
            this.g("Placeholder");
        }
        get label() {
            return this.w;
        }
        set label(a) {
            this.w = a;
            this.g("Label");
        }
        get disabled() {
            return this.h;
        }
        set disabled(a) {
            this.h = a;
            this.g("Disabled");
        }
        get required() {
            return this.l;
        }
        set required(a) {
            this.l = a;
            this.g("Required");
        }
        get defaultValue() {
            return this.r;
        }
        set defaultValue(a) {
            this.r = a;
            this.g("DefaultValue");
        }
        get name() {
            return this.x;
        }
        set name(a) {
            this.x = a;
            this.g("Name");
        }
        get invalid() {
            return this.i;
        }
        set invalid(a) {
            this.i = a;
            this.g("Invalid");
        }
        get inputOcurredRef() {
            return this.v;
        }
        set inputOcurredRef(a) {
            this.v = a;
            this.g("InputOcurredRef");
        }
        get focusRef() {
            return this.u;
        }
        set focusRef(a) {
            this.u = a;
            this.g("FocusRef");
        }
        get blurRef() {
            return this.t;
        }
        set blurRef(a) {
            this.t = a;
            this.g("BlurRef");
        }
    }
    WebInputBaseDescription.$t = /*@__PURE__*/ markType(WebInputBaseDescription, 'WebInputBaseDescription', Description.$);
    return WebInputBaseDescription;
})();
